pub fn cloud_score(
forward_scores: &CloudSearchResults,
reverse_scores: &CloudSearchResults,
) -> NatsExpand description
Compute the cloud score: the approximation of the forward score of the entire cloud.
pub fn cloud_score(
forward_scores: &CloudSearchResults,
reverse_scores: &CloudSearchResults,
) -> NatsCompute the cloud score: the approximation of the forward score of the entire cloud.