pub struct DisplayStrings {
pub profile_string: String,
pub target_string: String,
pub middle_string: String,
pub posterior_string: String,
}Fields
profile_string: StringThe display for the profile portion of the alignment
target_string: StringThe display for the target portion of the alignment
middle_string: StringThe display in between the profile and target
posterior_string: StringThe display for position-specific posterior probability bins