Sequence

Struct Sequence 

pub struct Sequence {
    pub name: String,
    pub details: Option<String>,
    pub length: usize,
    pub digital_bytes: Vec<u8>,
    pub utf8_bytes: Vec<u8>,
}
This holds the both the “digital” data and string data of a biological sequence.

Fields

name: String

The name of the sequence

details: Option<String>

The sequence details. If the sequence comes from a fasta, this is the information following the sequence name in the header

length: usize

The length of the sequence

digital_bytes: Vec<u8>

The “digital” data of the sequence. These are the string bytes, but mapped to [0u8..25u8]

utf8_bytes: Vec<u8>

The string data of the sequence. These are the UTF8 bytes that make up the sequence in the “normal” alphabet

Implementations

Source

impl Sequence

pub fn random_amino(length: usize, rng: &mut Lcg128Xsl64) -> Self

pub fn amino_from_fasta<P: AsRef<Path>>(path: P) -> Result<Vec<Self>>

pub fn from_digital(bytes: &[u8]) -> Result<Self>

pub fn from_utf8(bytes: &[u8]) -> Result<Self>