pub struct Cloud {
pub bounds: Vec<Bound>,
pub seq_len: usize,
pub prf_len: usize,
pub size: usize,
pub ad_start: usize,
pub ad_end: usize,
}Fields
bounds: Vec<Bound>seq_len: usizeprf_len: usizesize: usizead_start: usizead_end: usizeImplementations
Sourceimpl Cloud
impl Cloud
pub fn new(seq_len: usize, prf_len: usize) -> Self
pub fn iter(&self) -> Iter<'_, Bound>
pub fn first(&self) -> &Bound
pub fn last(&self) -> &Bound
pub fn resize(&mut self, new_size: usize)
pub fn reset(&mut self)
pub fn reuse(&mut self, seq_len: usize, prf_len: usize)
pub fn append(&mut self, bound: Bound)
pub fn target_len(&self) -> usize
pub fn profile_len(&self) -> usize
pub fn valid(&self) -> bool
pub fn validity(&self) -> CloudValidity
Sourcepub fn cloud_size(&self) -> usize
pub fn cloud_size(&self) -> usize
Get the total number of cells that exist within the cloud boundaries.
Sourcepub fn num_anti_diagonals(&self) -> usize
pub fn num_anti_diagonals(&self) -> usize
Get the number of anti-diagonals defined in the cloud.
Sourcepub fn trim_wings(&mut self) -> Result<()>
pub fn trim_wings(&mut self) -> Result<()>
This removes all of the protruding regions in the cloud that are unreachable from a traceback that traverses the entire cloud.
pub fn square_corners(&mut self)
pub fn advance_forward(&mut self)
pub fn advance_reverse(&mut self)
pub fn fill_rectangle( &mut self, seq_start: usize, prf_start: usize, seq_end: usize, prf_end: usize, )
pub fn bounding_box(&self) -> BoundingBox
pub fn left_offset_to(&mut self, other: &Self) -> Ordering
pub fn right_offset_to(&mut self, other: &Self) -> Ordering
pub fn merge(&mut self, other: &Self)
pub fn anti_diagonal_relationship(&self, other: &Self) -> Relationship
pub fn cloud_relationship(&self, other: &Self) -> Relationship
pub fn vec_image(&self, other: Option<&Self>) -> Result<Vec<Vec<u8>>>
pub fn image(&self) -> CloudImage